/*===========================================================================
Project name:		Romania Gender Assessment
Year:				2022/23
Datasets:			EU-LSF

---------------------------------------------------------------------------
Authors:			Britta Rude/Monica Robayo-Abril 
Dependencies:		World Bank
Creation Date:		March, 2023
Modification Date:  
Description: 		Labor Force Participation and child care

Notes: For background on household relations in Eu-silc see: https://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/gesis_papers/2016/GESIS-Papers_2016-10.pdf

=============================================================================*/






********************************************************************************
*Upload data

use "$data\EU_LSF\ROU_LFS_2010_2019.dta", clear


global weight coeff


*Available variables
********************************************************************************

*Women
codebook sex //0 missing
tab sex
tab sex, nolab
gen female = (sex==2)
tab female sex
label var female "Female"

label define femalev 0 "male" 1 "female"
label value female femalev
tab female


*Rural
codebook degurba //0 missing
gen rural = (degurba==3)
tab degurba rural
label var rural "Rural"

gen urban = (degurba!=3)
label define urbanv 0 "rural" 1 "urban"
label value urban urbanv
tab urban 



*age groups (age not available)
codebook age //0 missing
tab age
tab age, nolab //numbers are mean age in each group

*age group
gen agegroup = 0
replace agegroup = 1 if inrange(age, 16,24)
replace agegroup = 2 if inrange(age, 25,34)
replace agegroup = 3 if inrange(age, 35,44)
replace agegroup = 4 if inrange(age, 45,54)
replace agegroup = 5 if inrange(age, 55,64)
replace agegroup = 6 if age>64

label define agegroupv 0 "<16" 1 "16-24" 2 "25-34" 3 "35-44" 4 "45-54" 5 "55-64" 6 ">64"
label value agegroup agegroupv
tab agegroup
tab age agegroup //this is correct

*Age of youngest child (available at yearly)
tab hhageyg
tab hhageyg, nolab

*Age of youngest child (<15)
tab hhage14
tab hhage14, nolab

*Has youngest child being six
codebook hhage14
gen child6 = (hhage14==6) //code missing as zeros
tab hhage14 child6 //correct 
label var child6 "Youngest child six years old"

*Has youngest child being five, six, or seven
gen child567 = inrange(hhage14,5,7)
tab hhage14 child567 //correct
label var child567 "Youngest child 5-to-7 years old"

*Number of chidlren (<15)
tab hhnb0014
tab hhnb0014, nolab

*Number of person (independent of age)
tab hhnbpers
tab hhnbpers, nolab

*Migrant
tab national
gen migrant = (national!=0)
tab national migrant
label var migrant "Migrant"

*Married
tab marstat
tab marstat, nolab
gen married = (marstat==2)
tab marstat married
label var married "Married"

*Divorced
gen divorced = (marstat==0)
tab marstat divorced
label var divorced "Divorced"

*Employed
codebook ilostat
tab ilostat
tab ilostat, nolab

gen employed = (ilostat==1) if !missing(ilostat) //I also want to consider those not in the labor market, therefore have to consider those not in the labor market!! 
tab ilostat employed
tab ilostat employed, m
label var employed "Employed"

*Labor Force
gen lfp = (ilostat<3) if !missing(ilostat)
tab ilostat lfp
tab ilostat lfp, m
label var lfp "Labor force participation"

*Educ level 
codebook hatlev1d //code missing as zeros in this case 
tab hatlev1d
tab hatlev1d, nolab
gen highskilled = (hatlev1d==3)
tab hatlev1d highskilled
label var highskilled "High-skilled"

gen middleskilled = (hatlev1d==2)
tab middleskilled hatlev1d
label var middleskilled "Middle-skilled"

gen lowskilled = (hatlev1d==1)
tab lowskilled hatlev1d
label var lowskilled "Low-skilled"

*Educ level (ISCID-11)
tab hat11lev
tab hat11lev, nolab

codebook hat11lev


*education
gen noschool = (hat11lev==0) if !missing(hat11lev)
gen primary = (hat11lev==100) if !missing(hat11lev)
gen lowersecondary = (hat11lev==200) if !missing(hat11lev)
gen uppersecondary = inrange(hat11lev,300, 304) if !missing(hat11lev)
gen secondary = (lowersecondary==1 | uppersecondary==1) if !missing(hat11lev)
codebook secondary

gen postsecondary = (hat11lev==400) if !missing(hat11lev)

gen tertiary = (hat11lev==500 | hat11lev==600 | hat11lev==700) if !missing(hat11lev)
tab tertiary

gen phd = (hat11lev==800) if !missing(hat11lev)
tab phd


label var noschool "No schooling"
label var primary "Primary educ."
label var secondary "Secondary educ."
label var postsecondary "Post-secondary, non-tertiary"
label var tertiary "Short-cycle tertiary educ."
label var phd "PhD"

global educvars noschool primary secondary postsecondary tertiary phd


*Income decile
tab incdecil
tab incdecil, nolab

*Looking for a job
codebook seekwork
tab seekwork
tab seekwork, nolab
gen seekingwork = (seekwork==4) //code missing as zeros as those out of labor force are the control group
tab seekwork seekingwork
label var seekingwork "Seeking work"

*Part-time
codebook ftpt
tab ftpt
tab ftpt, nolab
gen parttime = (ftpt==2) //code missing as zeros as those out of labor force are the control group
tab ftpt parttime
label var parttime "Part-time work"

*Hours worked
tab hwusual
tab hwusual, m
tab hwusual, nolab

*Presence of father in household
tab hhparent
tab hhparent, nolab

*Presence of partner
tab hhpartnr
tab hhpartnr, nolab

gen hhpartner = (hhpartnr==1)
label var hhpartner "Partner lives in household"


*Global of vars
********************************************************************************

global vars age migrant married divorced hhpartner lowskilled middleskilled highskilled child6 hhage14 hhnb0014 hhnbpers hhnbwork hhnbinac employed parttime seekingwork incdecil hwusual


*Treatment and control groups 
********************************************************************************

*Mother

sort year hhnum hhseqnum 
list year hhnum hhseqnum hhmoth age in 1/100 if hhmoth!=0 //0 means that the motehr is not in the HH
list year hhnum hhseqnum hhmoth age in 1/100, nolab

codebook hhmoth //none is missing
tab hhmoth //29 different values, most often it is peron 02 in the HH roster
tab hhmoth, nolab

codebook hhnum //serial number of HH
codebook hhseqnum //Sequence number of person in HH

bysort year hhnum: egen motherid = max(hhmoth)
list year hhnum hhseqnum hhmoth motherid age in 1/100, nolab

gen mother = (motherid==hhseqnum)
tab motherid mother
list year hhnum hhseqnum hhmoth motherid mother age in 1/100, nolab //this is correct

tab sex mother //this seems correct; there are 105 mothers who are male, but they could be non-traditional family setups
tab hhchildr if mother==1
tab hhnb0014 if mother==1
tab hhnbchld if mother==1 //some children seem to be above 25 years old

*Mother (youngest child is six)
tab age if child6==1
list year hhnum hhseqnum child6 age if child6==1, nolab //this is already at the household level, and correct (age is in groups)

cap drop hhchild6
bysort year hhnum: egen hhchild6 = max(child6)
tab child6 hhchild6 //other HH members are not 6 years old

cap drop mother6
gen mother6 = (child6==1 & mother==1)
tab mother6
label var mother6 "Mother with six-year-old"

*Mother (youngest child is three and four)
cap drop mother3
gen mother3 = (mother==1 & (hhage14==3 | hhage14==4))
tab mother3
label var mother3 "Mother with three- or four-year-old"


*Mother (youngest child is five to seven)
cap drop mother567
gen mother567 = (mother==1 & inrange(hhage14, 5, 7))
tab mother567
label var mother567 "Mother with five- to seven-year-old"

*Women no kids
gen womennokids = (female==1 & hhnbchld==0) //later restrict age range
tab womennokids
label var womennokids "Women without kids"

*Grandparents in HH with youngest is six
cap drop opa6
gen opa6 = (age>62 & (hhage14==6))
tab opa6
label var opa6 "Grandparent in HH with six-year-old"


*Grandparents in HH with three-to-four-year old
cap drop opa3
gen opa3 = (age>62 & (hhage14==3 | hhage14==4))
tab opa3
label var opa3 "Grandparent in HH with three- or four-year-old"


***Define treatment variable
tab year //none are missing
gen post = (year>2011)
tab year post
label var post "Post2012"

***Define regional unemp rate
encode region, gen(regioni)

tab ilostat, m
gen unemp = (ilostat==2) if ilostat<3
tab unemp ilostat
egen unemp_reg=wtmean(unemp), by(year regioni) weight($weight)
tab unemp_reg
tab unemp_reg, m
label var unemp_reg "Average regional unempl. rate"


*Summary Table
********************************************************************************


eststo mom6: estpost summarize $vars [w=$weight] if inrange(age, 22, 47) & mother6==1
eststo mom3: estpost summarize $vars [w=$weight] if inrange(age, 22, 47) & mother3==1
eststo womennokids: estpost summarize $vars [w=$weight] if inrange(age, 22, 47) & womennokids==1

esttab mom6 mom3 womennokids using "$tables/summarytable.tex", replace ///
cell("mean(pattern(1 1 1) fmt(2)) sd(pattern(1 1 1) fmt(2))") ///
nogaps compress mtitle("Mother (6-year-old)" "Mother (3-to-4-year-old)" "Women without kids") label ///
title("Summary Statistics") addnote("Source: EU-LSF (2010-2019).")



*graph (all)
********************************************************************************

tab year

bysort year: sum employed [w=$weight] if womennokids==1 & inrange(age, 22, 47)

preserve

collapse (mean) employed [w=$weight] if inrange(age, 22, 47), by(year womennokids mother6 mother3)


*Unadjusted employment trends
twoway (line employed year if mother6==1) ///
(line employed year if mother3==1) ///
(line employed year if womennokids==1), ///
xline(2012, lcolor(black)) ///
xtitle("Year") ytitle("Employment rate") legend(label(1 "Mother (6-year-old)") label(2 "Mother (3-to-4-year-old)") label(3 "Women without kids")) note("Source: EU-LSF (2010-2019).") ylabel(0.5(0.1)0.9)

graph export "$figures\descriptive_employment.png", replace 


restore

*Unadjusted employemnt gap

cap drop type
gen type = "mom6" if mother6==1
replace type = "mom3" if mother3==1
replace type = "nomom" if womennokids==1

preserve

collapse (mean) employed [w=$weight] if inrange(age, 22, 47), by(year type)

drop if missing(type)

reshape wide employed, i(year) j(type) string

gen employmentgap = employednomom - employedmom6
label var employmentgap "Employment Gap"

twoway line employmentgap year, xtitle("Year") ytitle("Employment gap") note("Source: EU-LSF (2010-2019).") xline(2012, lcolor(black))

graph export "$figures\descriptive_employment_gap.png", replace 

restore



*graph - employment rate by rural/urban
********************************************************************************




preserve

collapse (mean) employed [w=$weight], by(urban year mother6 mother3)


*Unadjusted employment trends
twoway (line employed year if mother6==1 & urban==1) ///
(line employed year if mother3==1 & urban==1) ///
(line employed year if mother6==1 & urban==0) ///
(line employed year if mother3==1 & urban==0), ///
xline(2012, lcolor(black)) ///
xtitle("Year") ytitle("Employment rate") legend(label(1 "Mother (6-year-old) - urban") label(2 "Mother (3-to-4-year-old) - urban") label(3 "Mother (6-year-old) - rural") label(4 "Mother (3-to-4-year-old) - rural")) note("Source: EU-LSF (2010-2019).") ylabel(0.5(0.1)0.9)

graph export "$figures\descriptive_employment_urban.png", replace 


restore



*Final Table - women with three and four year old as control: First table in text
********************************************************************************

***Define outcome variable
global outcome employed

***Define basic controls
global vars age migrant married hhpartner lowskilled highskilled hhnbwork



*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post
estimate store margins

sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni)

margins, dydx(mother6) at(post=(0 1)) post
estimate store margins


sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck
estimate store margins


sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni)

margins, dydx(mother6) at(post=(0 1)) post noestimcheck
estimate store margins


sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck
estimate store margins


sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if type=="mom6" | type=="mom3", cluster(regioni) 

sum $outcome [w=$weight] if type=="mom6" | type=="mom3", d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6



***Output Table
esttab m1 m2 m3 m4 m5 m6 using "$tables/results__m3control.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates\label{tab:dd}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered.") replace







*Final Table (with age restriction) - women with three and four year old as control: First table in Appendix B1
********************************************************************************


*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) //effect is positive

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results__m3control_agerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates\label{tab:ddagerange}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of 20-49-year-old mothers of children between 3 and 4 or 6 years old.") replace


 

 
*Final Table (with age restriction, younger) - women with three and four year old as control: Second Table in Appendix B2
********************************************************************************


*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), cluster(regioni) 

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 42), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results__m3control_agerange_r.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates\label{tab:ddageranger}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered. The sample consists of 20-44-year-old mothers of children between 3 and 4 or 6 years old.") replace





*Final Table (without age restriction) - unweighted women with three and four year old as control: Third Table in Appendix B1
********************************************************************************

global outcome employed


*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg if (type=="mom6" | type=="mom3"), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg if (type=="mom6" | type=="mom3"), cluster(regioni) 

sum $outcome if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .001)
estadd local se=round(`r(sd)', 0.008)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results__m3control_unweighted.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(3 3 %~16s %~16s %~16s %~16s 0) label("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates\label{tab:ddunweighted}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of mothers of children between 3 and 4 or 6 years old.") replace





*Final Table (with age restriction) - women with no children as control: Table 4 in Appendix B1
********************************************************************************


*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), cluster(regioni) 

sum $outcome [w=$weight] if (type=="mom6" | type=="nomom") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results__nomomcontrol_agerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates\label{tab:ddnomom}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of 20-49-year-old mothers of six-year-old children and women without children.") replace






*Final Table (without age restriction) - women with three and four year old as control - Table 5 in Appendix B1
********************************************************************************

global outcome lfp

*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni)

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni)

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni)

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', .002)
estadd local se=round(`r(sd)', 0.007)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}' - no age restriction"\label{tab:lfpnoage}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of mothers of children between 3 and 4 or 6 years old.") replace





*Final Table (with age restriction) - women with three and four year old as control: Table 6 in Appendix B.1.
********************************************************************************

global outcome lfp
label var lfp "Labor force participation rate"

*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47)

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni)

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), cluster(regioni) 

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'\label{tab:lfp}") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of 20-49-year-old mothers of children between 3 and 4 or 6 years old.") replace





*Robustness Table - use mothers of 5,6,7 year old as treatment, women with three and four year old as control: Table 7 in Appendix B1
********************************************************************************

cap drop type2
gen type2 = "mom567" if mother567==1
replace type2 = "mom3" if mother3==1
tab type2

global outcome employed


*No controls
logit $outcome i.post i.mother567 i.post#i.mother567 [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) 

margins, dydx(mother567) at(post=(0 1)) post

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother567 i.post#i.mother567 $vars [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) 

margins, dydx(mother567) at(post=(0 1)) post

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother567 i.post#i.mother567 i.regioni i.year $vars [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) 

margins, dydx(mother567) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother567 i.post#i.mother567 i.regioni i.year $vars unemp_reg [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) 

margins, dydx(mother567) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4






*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother567 i.post#i.mother567 i.regioni i.year $vars unemp_reg [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother567) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother567 i.post#i.mother567 i.regioni i.year $vars unemp_reg [iw=$weight] if type2=="mom567" | type2=="mom3", cluster(regioni) 

sum $outcome [w=$weight] if type2=="mom567" | type2=="mom3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results__m3control_children567.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates"\label{tab:ch567}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered.") replace






*Heterogeneity - Table 3 in Section 5.2. 
********************************************************************************

*Rural already defined above 

gen addchild = (hhnb0014>1)
tab hhnb0014 addchild
label var addchild "Additional child(ren)"

gen elderlyhh = (hhnbold>0)
tab hhnbold elderlyhh
label var elderlyhh "Elderly in household"

gen workinghh = (hhnbwork>0)
tab hhnbwork workinghh //number of employed
label var workinghh "Working HH mebmers"

codebook stapro
tab stapro
gen selfemployed = (stapro<3) //my comparison group are all those who are not self-employed (also out of labor market)
tab stapro selfemployed
label var selfemployed "Self-employed"

tab hhpartner //partner in same hh

global vars age migrant married hhpartner lowskilled highskilled hhnbwork

global outcome employed


*Rural/urban
global vars age migrant married hhpartner lowskilled highskilled hhnbwork

logit $outcome i.post i.mother6 i.post#i.mother6#rural i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) rural=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m1



*Additional child
global vars age migrant married hhpartner lowskilled highskilled hhnbwork

logit $outcome i.post i.mother6 i.post#i.mother6#addchild i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) addchild=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m2






*Elderly HH
global vars age migrant married hhpartner lowskilled highskilled hhnbwork

logit $outcome i.post i.mother6 i.post#i.mother6#elderlyhh i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) elderlyhh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m3




*Partner HH
global vars age migrant married lowskilled highskilled hhnbwork

logit $outcome i.post i.mother6 i.post#i.mother6#hhpartner i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) hhpartner=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Other working HH

global vars age migrant married hhpartner lowskilled highskilled

logit $outcome i.post i.mother6 i.post#i.mother6#i.workinghh i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) workinghh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5


*Self-employed

global vars age migrant married hhpartner lowskilled highskilled

logit $outcome i.post i.mother6 i.post#i.mother6#i.selfemployed i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3"), cluster(regioni)

margins, dydx(mother6) at(post=(0 1) selfemployed=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6



esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_het.tex", booktabs ///
se nostar ar2 nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'"\label{tab:het}) nonumbers ///
mtitle("Rural" "Child" "Elderly" "Partner in HH" "Employed in HH" "Self-employed") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of mothers of children between 3 and 4 or 6 years old.") replace





*Impact on grandparents - Table 1 in Appendix B.2.
****************************************************************************************************************************************

gen type3 = "opa6" if opa6==1
replace type3 = "opa3" if opa3==1
tab type3
tab type3 opa6

global outcome employed


*No controls
logit $outcome i.post i.opa6 i.post#i.opa6 [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni)

margins, dydx(opa6) at(post=(0 1)) post

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.opa6 i.post#i.opa6 $vars [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni)

margins, dydx(opa6) at(post=(0 1)) post

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.opa6 i.post#i.opa6 i.regioni i.year $vars [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni) 

margins, dydx(opa6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.opa6 i.post#i.opa6 i.regioni i.year $vars unemp_reg [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni) 

margins, dydx(opa6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4






*Demographic variables and fixed effects - probit
probit $outcome i.post i.opa6 i.post#i.opa6 i.regioni i.year $vars unemp_reg [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(opa6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.opa6 i.post#i.opa6 i.regioni i.year $vars unemp_reg [iw=$weight] if type3=="opa6" | type3=="opa3", cluster(regioni) 

sum $outcome [w=$weight] if type3=="opa6" | type3=="opa3", d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_`outcome'_m3control_grandparents.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates of grand-parents"\label{tab:opa}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered.") replace












*Part-time work - Table 5 in Section 6 
********************************************************************************

global outcome parttime

*No controls
logit $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1


margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3"), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & employed==1, d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) 

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & inrange(age, 22, 47), d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'") nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of employed mothers of children between 3 and 4 or 6 years old.") replace










*Usual hours worked - Table 6 in Section 6 
********************************************************************************

global outcome hwusual 

*No controls
reg $outcome i.post i.mother6 i.post#i.mother6 [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, r

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & employed==1, d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
reg $outcome i.post i.mother6 i.post#i.mother6 $vars [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni)

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & employed==1, d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni) 

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") & employed==1, d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (type=="mom6" | type=="mom3") & employed==1, cluster(regioni)

sum $outcome [w=$weight] if (type=="mom6" | type=="mom3") &  employed==1, d //for initial value
estadd local mea `r(mean)'
estadd local se `r(sd)'
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4



esttab m1 m2 m3 m4 using "$tables/results_${outcome}_m3control_agerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'"\label{tab:hours}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit") ///
addnote("Source: EU-LSF (2010-2019). Standard errors are clustered." "The sample consists of employed mothers of children between 3 and 4 or 6 years old.") replace







