/*===========================================================================
Project name:		Romania Gender Assessment
Year:				2022/23
Datasets:			EU-SILC

---------------------------------------------------------------------------
Authors:			Britta Rude/Monica Robayo-Abril 
Dependencies:		World Bank
Creation Date:		March, 2023
Modification Date:  
Description: 		Labor Force Participation and child care

Notes: For background on household relations in Eu-silc see: https://www.gesis.org/fileadmin/upload/forschung/publikationen/gesis_reihen/gesis_papers/2016/GESIS-Papers_2016-10.pdf

=============================================================================*/


********************************************************************************
*Child-Care information - Triple difference
********************************************************************************



*Upload data
********************************************************************************

use "$data\EU_SILC\SILC_2010_2020.dta", clear

tab ctry_n //This data is only for Romania

tab year_n //2010 to 2020

***generate hhrank variable for descriptives
egen hhrank=rank(rx010), by(year country hhid_n) unique
tab hhrank

***Personal cross-sectional weights
global weight rb050 


*Prepare variable of interest
********************************************************************************

***Employed
cap drop employed

codebook rb210
gen employed = (rb210==1) //The reference group are also those who are not in the labor market 

tab employed rb210, m

tab employed pl040
tab employed rb210

label var employed "Employed"

***Gender
tab pb150
tab pb150, nolab
codebook pb150
gen sex=pb150
tab sex, m
tab sex, nolab

gen female=(sex==2)
tab female

***Age
codebook rx020
tab rx020
gen age=rx020 //age at the end of the income reference period
codebook rx010
tab rx010
replace age=rx010 if age==. //age at date of interview
assert age!=.

gen youth = 0
replace youth = 1 if inrange(age, 20, 29)
tab age if youth==1

gen adults = 0 
replace adults = 1 if inrange(age, 30, 49)
tab age if adults==1

gen seniors = 0
replace seniors = 1 if inrange(age, 50, 64)
tab age if seniors==1

gen child = (age<16)
tab child

bys hhid: egen child_hh = max(child)
tab child_hh

gen youngchild = (age<6)
tab youngchild

bys hhid: egen youngchild_hh = max(youngchild)
tab youngchild_hh

*asiste (preschool)
tab age if !missing(rl010) //0 to (including) 6, but also some cases for 7-10
tab age if !missing(rl020) //6-13, but also some for 0-5

codebook rl010 if age<6 //Missing .: 163313
tab age if missing(rl010) & age<6 //all age groups

tab rl010 if age<6, m
cap drop asiste
gen asiste = (rl010>0)

replace asiste=0 if missing(rl010) //--> Treat missing as zero
sum asiste if age<6 

***Table 1 in Appendix A.2.
estpost tab age asiste if age<16
esttab . using "$tables\asiste_preschool_tab.tex", replace unstack nogaps cells(b) nomti title(Data on preschool assistance\label{tab:asiste})

***Figure A.1.
hist rl010, color(blue)
graph export "$figures\hist_preschool.png", replace

hist rl010 if age==6, color(blue)
graph export "$figures\hist_preschool_six.png", replace

*asiste (compulsory)
codebook rl020
gen asiste_school = (rl020>0)

replace asiste_school=0 if missing(rl020) //--> I now treat missing as zero
sum asiste_school if age<13

*Table A.2.
estpost tab age asiste_school if age<16
esttab . using "$tables\asiste_school_tab.tex", replace unstack nogaps cells(b) nomti nonum nodep title(Data on  compulsory school assistance\label{tab:asisteschool})

*Figure A.2.
hist rl020, color(blue)
graph export "$figures\hist_school.png", replace

hist rl020 if age==6, color(blue)
graph export "$figures\hist_school_six.png", replace


*asiste (combined)
tab asiste asiste_school

cap drop asiste_combined
gen asiste_combined = (rl010>0 | rl020>0)
replace asiste_combined=0 if missing(rl020) & missing(rl010) //--> I now treat missing as zero
sum asiste_combined if age<16

sum asiste_combined [w=$weight] if age<16
sum asiste_combined [w=$weight] if age==6

*Table A.3.
estpost tab age asiste_combined if age<16 //unweighted for data background
esttab . using "$tables\asiste_schoolcombined_tab.tex", replace unstack nogaps cells(b) nomti nonum nodep title(Data on preschool and compulsory school assistance\label{tab:asisteschoolcombined})

*asiste (hours)
hist rl010
codebook rl010
cap drop asiste_hours
gen asiste_hours = rl010
codebook rl020
hist rl020
replace asiste_hours = rl020 if missing(rl010)

*Figure A.3.
hist asiste_hours, color(blue)
graph export "$figures\hist_school_combined.png", replace

hist asiste_hours if age==6, color(blue)
graph export "$figures\hist_school_combined_six.png", replace


*Asiste HH
bys year hhid: egen asiste_hh = max(asiste_combined)
tab asiste_hh if youngchild_hh==1
tab asiste_hh if age==6 
sum asiste_hh [w=$weight] if age==6
sum asiste_hh [w=${weight}] if age==6 & hhrank==1

gen child6 = (age==6)
bys year hhid: egen hh_child6 = max(child6)
sum hh_child6
label var hh_child6 "HH with six-year-old child"

gen child34 = (inrange(age, 3,4))
bys year hhid: egen hh_child34 = max(child34)
sum hh_child34
label var hh_child34 "HH with three- to four-year-old child"

gen asiste_combined_6 = asiste_combined
replace asiste_combined_6=. if age!=6
sum asiste_combined_6
label var asiste_combined_6 "Six-year-old attends (pre)school"

bys year hhid: egen asiste_combined_6_hh = max(asiste_combined_6)
sum asiste_combined_6_hh [w=$weight]
sum asiste_combined_6_hh [w=$weight] if hh_child6==1
label var asiste_combined_6_hh "HH with six-year-old attending (pre)school"

cap drop asiste_combined_34
gen asiste_combined_34 = asiste_combined
replace asiste_combined_34=. if !inrange(age, 3,4)
sum asiste_combined_34
label var asiste_combined_34 "Three- to four-year-old attends (pre)school"

cap drop asiste_combined_34_hh
bys year hhid: egen asiste_combined_34_hh = max(asiste_combined_34)
sum asiste_combined_34_hh [w=$weight]
sum asiste_combined_34_hh [w=$weight] if hh_child6==1
label var asiste_combined_34_hh "HH with three-to four-year-old attending (pre)school"

global asistvars hh_child6 asiste_combined_6 asiste_combined_6_hh hh_child34 asiste_combined_34 asiste_combined_34_hh

*Figure A.4.
preserve

collapse (mean) asiste_combined_6_hh [w=$weight] if hh_child6==1 & hhrank==1, by(year)

label var asiste_combined_6_hh "Attendance rate (six-year-old)"

twoway line asiste_combined_6_hh year
graph export "$figures\attendancerate_6_hh.png", replace

restore


*Table A.4.
preserve 

keep $asistvars $weight

estpost summarize $asistvars [w=${weight}]

esttab . using "$tables\summary_hhasist.tex", cells("mean(fmt(%8.2f)) sd(fmt(%8.2f))") nonum collabels("Mean" "St. Dev.") label replace

restore 


***Education
tab pe040
tab pe040, nolab
bys year: tab pe040
bys year: tab pe040, nolab //before 2014, it was different


gen noschool = (pe040==0)

gen primary = (pe040==100)
replace primary = 1 if pe040==1 & year<2014
tab primary
tab pe040 primary

gen lowersecondary = (pe040==200)
replace lowersecondary = 1 if pe040==2 & year<2014
tab lowersecondary
tab pe040 lowersecondary


gen uppersecondary = (pe040==300)
replace uppersecondary = 1 if pe040==3 & year<2014
tab uppersecondary
tab pe040 uppersecondary


gen secondary = (lowersecondary==1 | uppersecondary==1)
codebook secondary


gen vocational = inrange(pe040, 340,450)
replace vocational = 1 if pe040==4 & year<2014
tab vocational
tab pe040 vocational


gen tertiary = (pe040==500 | pe040==600 | pe040==700)
replace tertiary = 1 if pe040==5 & year<2014
tab tertiary
tab pe040 tertiary


gen phd = (pe040==800)
tab phd

label var noschool "No schooling"
label var primary "Primary educ."
label var secondary "Secondary educ."
label var tertiary "Tertiary educ."
label var phd "PhD"

global educvars noschool primary secondary tertiary phd

*internet
codebook pd080
tab pd080
gen internet = (pd080==1)
tab pd080 internet
label var internet "Internet access at home"

*urban
codebook db100
tab db100
gen urban=1
replace urban=0 if db100==3
tab urban db100

*Child
bys year hhid: egen hhage14 = sum(child)
sum hhage14

*Mother

rename pb030 pers_id

cap drop mother
gen mother=0

cap drop mtemp*
cap drop mompers*

foreach i of numlist 1/17{
gen long mtemp`i'=rb230 if hhrank==`i' //Step1
egen long mompers`i'=mean(mtemp`i'), by(year country hhid_n) //Step2
replace mother = (pers_id==mompers`i') if !missing(mompers`i') //Step3

}

tab mother
codebook mother

label var mother "Mother"

tab age if mother==1
sum mother [w=$weight]
sum age [w=$weight] if mother==1
tab female if mother==1 




*Age of child
cap drop age_youngestchild
bys year hhid: egen age_youngestchild = min(age)
tab age_youngestchild
tab age_youngestchild, m


*Mother of six-year-old
cap drop mother6
gen mother6 = (hh_child6==1 & mother==1)
tab mother6 //1,015
label var mother6 "Mother with six-year-old"

tab hh_child6 if hhrank==1 //1,050
codebook pb170 if hh_child6==1 //420


*Mother of three and four year old
cap drop mother3
gen mother3 = (mother==1 & hh_child34)
tab mother3 //1,655 
label var mother3 "Mother with three- or four-year-old"

tab hh_child34 if hhrank==1 //1,680
codebook pb170 if hh_child34==1 //676


*Summary of mothers - Table A.5.
estpost summarize mother mother6 mother3 [w=${weight}]

esttab . using "$tables\summary_mothers.tex", cells("mean(fmt(%8.4f)) sd(fmt(%8.4f))") nonum collabels("Mean" "St. Dev.") label replace



*Other controls

bys year hhid: egen member = count(age)
sum member

tab pb220a
tab pb220a, nolab
gen migrant = (pb220a!="LOC")
tab migrant pb220a

tab pb190
tab pb190, nolab
gen married = (pb190==2)

gen divorced = (pb190==5)

gen hhpartner = (!missing(pa110))
tab hhpartner
codebook hhpartner //none is missing

bys year hhid: egen hhnbpers = count(age)
sum hhnbpers

bys year hhid: egen hhnbwork = sum(employed)
sum hhnbwork

gen parttime = (pl031==2) //part-time employee (not self-employed)
tab parttime

encode db040, gen(regioni)


gen unemployed = (rb210==2) if rb210<3
egen unemp_reg=wtmean(unemployed), by(year regioni) weight($weight)

gen inc_pc=(hx090*hx050)/hx040

forval i=2010/2020{
	cap drop inc_pc_q`i'
	xtile inc_pc_q`i' = inc_pc [w=rb050] if year==`i', nq(5)

	tab inc_pc_q`i'
	tab inc_pc_q`i' [iw=rb050]
	
	sum inc_pc if inc_pc_q`i'==1
	sum inc_pc if inc_pc_q`i'==5
}

gen b40 = 0 
forval i=2010/2020{
replace b40 = (inc_pc_q`i'<3) if year==`i'
tab inc_pc_q`i' b40
}

label define b40va 0 "t60" 1 "b40"
label value b40 b40va
label var b40 "Bottom 40"
tab b40


global vars age migrant married divorced hhpartner $educvars hhage14 hhnbpers hhnbwork parttime hy020

label var age "Age"
label var married "Married"
label var divorced "Divorced"
label var migrant "Migrant"
label var hhpartner "Partner in HH"
label var hhage14 "HH with child (<15)"
label var hhnbpers "HH members"
label var hhnbwork "No. of working HH members"
label var parttime "Part-time work"



gen post = (year>2011)
tab year post
label var post "Post-reform"

*Summary statistic of mother6 versus mother34 - Table A.6.
***Summary Table of Baseline Characteristics
eststo six: estpost summarize $vars post [w=$weight] if mother6==1
eststo threefour: estpost summarize $vars post [w=$weight] if mother3==1

esttab six threefour using "$tables/baselincharacteristics.tex", replace ///
cell("mean(pattern(1 1) fmt(2)) sd(pattern(1 1) fmt(2))") ///
nogaps compress mtitle("Mothers (six-year-olds)" "Mothers (three- to four-year-olds)") label tex ///
title(Characteristics \label{tab:characteristics}) addnote("Source: EU-SILC (2010-2020).")





***************************************************************************************************************************************
*Triple difference
***************************************************************************************************************************************

global outcome employed


*Without age restriction + additional interactions
****************************************************************************************


*No controls
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1




*Demographic variables
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 $vars [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni)

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) //effect is positive

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange_triple2_eusilc_noagerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'"\label{tab:dddr}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-SILC (2010-2020). Standard errors are clustered." "The sample consists of mother of children between 3 and 4 or 6 years old.") replace







*Without age restriction and additional interactions: Table B9 in Appendix B3
****************************************************************************************


*No controls
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1




*Demographic variables
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 $vars [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) difficult iterate(1000) technique(bhhh) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.asiste_hh i.mother6 i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1), cluster(regioni) 

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange_triple_eusilc_noagerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'"\label{tab:ddd}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-SILC (2010-2020). Standard errors are clustered." "The sample consists of mother of children between 3 and 4 or 6 years old.") replace




***Age restirction (and no additional interaction term) - Table B10 in Appendix B3
*********************************************************************************************************************************

*No controls
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 $vars [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) difficult iterate(1000) technique(bhhh)

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni)

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange_triple_eusilc.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates - Triple difference estimation with age restriction"\label{tab:dddrr}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-SILC (2010-2020). Standard errors are clustered." "The sample consists of 20-49-year-old mother of children between 3 and 4 or 6 years old.") replace





*Additional interaction terms - with age restriction
**********************************************************************************************


*No controls
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1



*Demographic variables
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 $vars i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
logit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4




*Demographic variables and fixed effects - probit
probit $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) difficult iterate(1000) technique(bhhh)

margins, dydx(mother6) at(post=(0 1) asiste_hh=(0 1)) post noestimcheck

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m5




*Demographic variables and fixed effects - ols
reg $outcome i.post i.asiste_hh i.post#i.asiste_hh#i.mother6 i.regioni i.year $vars unemp_reg i.post#i.asiste_hh i.post#i.mother6 i.asiste_hh#i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), cluster(regioni) 

sum $outcome [w=$weight] if (mother3==1 | mother6==1) & inrange(age, 20, 49), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m6




esttab m1 m2 m3 m4 m5 m6 using "$tables/results_${outcome}_m3control_agerange_triple_eusilc_int.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on employment rates - Triple difference estimation with age restriction and interaction term"\label{tab:dddageint}) nonumbers ///
mtitle("Logit" "Logit" "Logit" "Logit" "Probit" "OLS") ///
addnote("Source: EU-SILC (2010-2020). Standard errors are clustered." "The sample consists of 20-49-year-old mother of children between 3 and 4 or 6 years old.") replace




***********************************************************************************************************************
*Labor Income - Table 7 in Section 6 
************************************************************************************************************************************

global outcome py010g



*No controls
reg $outcome i.post i.mother6 i.post##i.mother6 [iw=$weight] if (mother3==1 | mother6==1) & employed==1, cluster(regioni)

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind No
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m1




*Demographic variables
reg $outcome i.post i.mother6 i.post##i.mother6 $vars [iw=$weight] if (mother3==1 | mother6==1) & employed==1, cluster(regioni) 

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe No
estadd local statefe No
estadd local unemp No

est sto m2




*Demographic variables and fixed effects
reg $outcome i.post i.mother6 i.post##i.mother6 i.regioni i.year $vars [iw=$weight] if (mother3==1 | mother6==1) & employed==1, cluster(regioni)

sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp No

est sto m3




*Demographic variables and fixed effects and unemp rate
reg $outcome i.post i.mother6 i.post#i.mother6 i.regioni i.year $vars unemp_reg [iw=$weight] if (mother3==1 | mother6==1) & employed==1, cluster(regioni) 


sum $outcome [w=$weight] if (mother3==1 | mother6==1), d //for initial value
estadd local mea=round(`r(mean)', 0.001)
estadd local se=round(`r(sd)', 0.001)
estadd local ind Yes
estadd local datefe Yes
estadd local statefe Yes
estadd local unemp Yes

est sto m4


esttab m1 m2 m3 m4 using "$tables/results_${outcome}_m3control_agerange_eusilc_noagerange.tex", booktabs ///
se nostar ar2 drop(*year *regioni $vars unemp_reg) nobaselevels noconstant ///
stats(mea se ind datefe statefe unemp N, fmt(a3 a3 %~16s %~16s %~16s 0) labels("Mean (Dep. Var)" "St. Dv. (Dep. Var.)" "Demographic controls" "Year fixed effects" "State fixed effects" "Region by year unemployment rate" "N")) ///
label title("The 2012 reform effect on `: variable label ${outcome}'"\label{tab:wage}) nonumbers ///
mtitle("OLS" "OLS" "OLS" "OLS") ///
addnote("Source: EU-SILC (2010-2020). Standard errors are clustered." "The sample consists of employed mother of children between 3 and 4 or 6 years old.") replace


